<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       ofb
 * @since      1.0.0
 *
 * @package    Ofb
 * @subpackage Ofb/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ofb
 * @subpackage Ofb/admin
 * @author     ORION <help@orionorigin.com>
 */
class Ofb_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;
	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 *  Set  admin styles
	 */
	public function enqueue_styles()
	{
		if (class_exists('vpc')) {
			if (is_vpc_admin_screen()) {
				wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/ofb-admin.css', array(), $this->version, 'all');
				wp_enqueue_style('o-ui', plugin_dir_url(__FILE__) . 'css/UI.css', array(), $this->version, 'all');
				wp_enqueue_style('o-ui', plugin_dir_url(__FILE__) . 'css/UI.min.css', array(), $this->version, 'all');
				wp_enqueue_style('o-tooltip', plugin_dir_url(__FILE__) . 'css/tooltip.min.css', array(), $this->version, 'all');
				wp_enqueue_style('o-bs-modal-css', plugin_dir_url(__FILE__) . 'css/modal/modal.min.css', array(), $this->version, 'all');
				wp_enqueue_style('o-flexgrid', plugin_dir_url(__FILE__) . 'css/flexiblegs.css', array(), $this->version, 'all');
				wp_enqueue_style('template', plugin_dir_url(__FILE__) . 'css/template.css', array(), $this->version, 'all');
			}
		}
	}

	/**
	 * Set admin script
	 */
	public function enqueue_scripts()
	{
		if (class_exists('vpc')) {
			if (is_vpc_admin_screen()) {
				wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/ofb-admin.js', array('jquery', 'o-admin'), $this->version, false);
				wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/modal.js', array('jquery', 'o-admin'), $this->version, false);
				wp_enqueue_script('o-admin', plugin_dir_url(__FILE__) . 'js/o-admin.js', array('jquery', 'jquery-ui-sortable'), $this->version, false);
				wp_enqueue_script('o-modal-js', plugin_dir_url(__FILE__) . 'js/modal/modal.min.js', array('jquery'), $this->version, false);
			}
		}
	}

	/**
	 * Runs the new version check and upgrade process
	 *
	 * @return \Vpc_Ofb_Updater
	 */
	public function get_updater()
	{
		if (class_exists('vpc')) {
			do_action('vpc_before_init_updater');
			require_once VPC_OFB_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-ofb-updater.php';
			$updater = new Vpc_Ofb_Updater();
			$updater->init();
			require_once VPC_OFB_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-ofb-updating-manager.php';
			$updater->set_update_manager(new Vpc_Ofb_Updating_Manager(VPC_OFB_VERSION, $updater->version_url(), VPC_OFB_MAIN_FILE));
			do_action('vpc_after_init_updater');
			return $updater;
		}
	}

	/**
	 * Function to add new options to the global settings.
	 *
	 * @param array $global_settings Global settings options list.
	 * @return array                 Global settings options list.
	 */
	public function add_global_settings($global_settings)
	{
		$begin = array(
			'type'  => 'sectionbegin',
			'id'    => 'vpc-ofb-container',
			'table' => 'options',
		);

		$end = array('type' => 'sectionend');

		$license_key = array(
			'title'   => __('Form builder add on license key', 'vpc'),
			'name'    => 'vpc-options[purchase-code-form-builder-add-on]',
			'type'    => 'text',
			'desc'    => __('This is the licence key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://orionorigin.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?', 'vpc'),
			'default' => '',
		);

		array_push($global_settings, $begin);
		array_push($global_settings, $license_key);
		array_push($global_settings, $end);
		return $global_settings;
	}

	/**
	 *  Create ofb custom post type
	 */
	public function register_ofb()
	{

		$labels = array(
			'name'               => _x('All Forms', 'ofb'),
			'singular_name'      => _x('Form', 'ofb'),
			'menu_name'          => __('Form settings', 'ofb'),
			'parent_item_colon'  => __('Parent Form:', 'ofb'),
			'all_items'          => __('All Forms', 'ofb'),
			'view_item'          => __('View Forms', 'ofb'),
			'add_new_item'       => __('Add New Form', 'ofb'),
			'add_new'            => __('Add New', 'ofb'),
			'edit_item'          => __('Edit Form', 'ofb'),
			'update_item'        => __('Update Form', 'ofb'),
			'search_items'       => __('Search Form', 'ofb'),
			'not_found'          => __('Not found', 'ofb'),
			'not_found_in_trash' => __('Not found in Trash', 'ofb'),
		);
		$args   = array(
			'label'               => __('ofb', 'ofb'),
			'description'         => __('Form settings', 'ofb'),
			'labels'              => $labels,
			'supports'            => array('title'),
			'hierarchical'        => false,
			'public'              => false,
			'show_ui'             => true,
			'show_in_menu'        => false,
			'show_in_nav_menus'   => false,
			'show_in_admin_bar'   => true,
			'menu_position'       => 9,
			'menu_icon'           => 'dashicons-tickets-alt',
			'can_export'          => true,
			'has_archive'         => false,
			'exclude_from_search' => false,
			'publicly_queryable'  => false,
			'rewrite'             => false,
			'capability_type'     => 'post',
		);
		register_post_type('ofb', $args);
	}

	/**
	 * Get ofb columns
	 *
	 * @param array $columns The screen columns array.
	 * @return int
	 */
	public function get_ofb_screen_layout_columns($columns)
	{
		$columns['ofb'] = 1;
		return $columns;
	}

	/**
	 * Added form builder screen layout.
	 *
	 * @return int
	 */
	public function get_ofb_config_screen_layout()
	{
		return 1;
	}

	/**
	 * Reorder ofb metax box
	 *
	 * @param array $order The user order.
	 * @return string
	 */
	public function metabox_order($order)
	{
		$order['advanced'] = 'slugdiv,ofb_box,submitdiv';
		return $order;
	}

	/**
	 * Add ofb meta box
	 */
	public function meta_box_ofb()
	{
		add_meta_box(
			'ofb_box',
			__('Form settings', 'ofb'),
			(array($this, 'ofb_post_repeatable_field')),
			'ofb'
		);
	}

	/**
	 * Create form fields
	 *
	 * @global type $o_row_templates
	 * @param object $post The form post object.
	 */
	public function ofb_post_repeatable_field($post)
	{
?>
		<div class='block-form'>
			<?php
			$begin = array(
				'type' => 'sectionbegin',
				'id'   => 'ofb-config-container',
			);
			$type = array(
				'title'		 => __('Type', 'ofb'),
				'name'		 => 'type',
				'type'		 => 'select',
				'options'	 => apply_filters(
					'vpc_form_type_option',
					array(
						'text'		 => 'Text',
						'textarea'	 => 'Textarea',
						'radio'		 => 'Radio',
						'checkbox'	 => 'Checkbox',
						'select'	 => 'Select',
						'email'		 => 'Email',
						'file'		 => 'File',
						// 'url' => 'URL',
						// 'tel' => 'Tel',
						'number' => 'Number',
						// 'date' => 'Date',
					)
				),
				'class'		 => 'ofb_types',
				'id'		 => 'ofb_types',
				'default'	 => 'text',
			);

			$length = array(
				'title' => __('Length', 'ofb'),
				'name'  => 'length',
				'type'  => 'number',
				'class' => 'ofb-length',
			);

			$label = array(
				'title' => __('Label', 'ofb'),
				'name'  => 'label',
				'type'  => 'text',
				'class' => 'ofb-label',
			);
			$name  = array(
				'title' => __('Name', 'ofb'),
				'name'  => 'name',
				'type'  => 'text',
				'class' => 'ofb-name',
			);

			$required = array(
				'title'   => __('Required', 'ofb'),
				'name'    => 'required',
				'type'    => 'radio',
				'options' => array(
					'Yes' => 'Yes',
					'No'  => 'No',
				),
				'default' => 'Yes',
				'class'   => 'ofb-required',
			);

			$price        = array(
				'title'             => __('Price', 'ofb'),
				'name'              => 'price',
				'type'              => 'number',
				'class'             => 'ofb-price',
				'custom_attributes' => array('step' => 'any'),
			);
			$option_price = array(
				'title'             => __('Price', 'ofb'),
				'name'              => 'option_price',
				'type'              => 'number',
				'class'             => 'ofb-option_price',
				'custom_attributes' => array('step' => 'any'),
			);

			$option_name = array(
				'title' => __('Label', 'ofb'),
				'name'  => 'label',
				'type'  => 'text',
				'class' => 'ofb-option-name',
			);

			$option_value = array(
				'title' => __('Option value', 'ofb'),
				'name'  => 'op_value',
				'type'  => 'text',
				'class' => 'ofb-option-value',
			);

			$type = array(
				'title'   => __('Type', 'ofb'),
				'name'    => 'type',
				'type'    => 'select',
				'options' => apply_filters(
					'vpc_form_type_option',
					array(
						'text'     => 'Text',
						'textarea' => 'Textarea',
						'radio'    => 'Radio',
						'checkbox' => 'Checkbox',
						'select'   => 'Select',
						'email'    => 'Email',
						'file'     => 'File',
					)
				),
				'class'   => 'ofb_types',
				'id'      => 'ofb_types',
				'default' => 'text',
			);
			$type = array(
				'title'		 => __('Type', 'ofb'),
				'name'		 => 'type',
				'type'		 => 'select',
				'options'	 => apply_filters(
					'vpc_form_type_option',
					array(
						'text'		 => 'Text',
						'textarea'	 => 'Textarea',
						'radio'		 => 'Radio',
						'checkbox'	 => 'Checkbox',
						'select'	 => 'Select',
						'email'		 => 'Email',
						'file'		 => 'File',
						'number' => 'Number',

					)
				),
				'class'		 => 'ofb_types',
				'id'		 => 'ofb_types',
				'default'	 => 'text',
			);

			$length = array(
				'title' => __('Length', 'ofb'),
				'name'  => 'length',
				'type'  => 'number',
				'class' => 'ofb-length',
			);

			$label = array(
				'title' => __('Label', 'ofb'),
				'name'  => 'label',
				'type'  => 'text',
				'class' => 'ofb-label',
			);
			$name  = array(
				'title' => __('Name', 'ofb'),
				'name'  => 'name',
				'type'  => 'text',
				'class' => 'ofb-name',
			);

			$required = array(
				'title'   => __('Required', 'ofb'),
				'name'    => 'required',
				'type'    => 'radio',
				'options' => array(
					'Yes' => 'Yes',
					'No'  => 'No',
				),
				'default' => 'Yes',
				'class'   => 'ofb-required',
			);

			$price        = array(
				'title'             => __('Price', 'ofb'),
				'name'              => 'price',
				'type'              => 'number',
				'class'             => 'ofb-price',
				'custom_attributes' => array('step' => 'any'),
			);
			$option_price = array(
				'title'             => __('Price', 'ofb'),
				'name'              => 'option_price',
				'type'              => 'number',
				'class'             => 'ofb-option_price',
				'custom_attributes' => array('step' => 'any'),
			);

			$option_name = array(
				'title' => __('Label', 'ofb'),
				'name'  => 'label',
				'type'  => 'text',
				'class' => 'ofb-option-name',
			);

			$option_value = array(
				'title' => __('Option value', 'ofb'),
				'name'  => 'op_value',
				'type'  => 'text',
				'class' => 'ofb-option-value',
			);

			$option_min = array(
				'title' => __('Min', 'opo'),
				'name' => 'op_min',
				'type' => 'number',
				'custom_attributes' => array('step' => 'any'),
				'class' => 'ofb-min',
				// 'col_class' => 'ofb-option-min-column',
				// 'col_css'      => 'display:none',
			);

			$option_max = array(
				'title' => __('Max', 'opo'),
				'name' => 'op_max',
				'type' => 'number',
				'custom_attributes' => array('step' => 'any'),
				'class' => 'ofb-max',
				// 'col_class' => 'ofb-option-max-column',
				// 'col_css'      => 'display:none',
			);

			$option_default = array(
				'title'   => __( 'Default', 'ofb' ),
				'name'    => 'default',
				'type'    => 'radio',
				'options' => array( 1 => '' ),
				'class'   => 'default-config',
				'tip'     => 'yes',
			);

			$options = apply_filters(
				'vpc_form_components_options_fields',
				array(
					'title'         => __('Options', 'ofb'),
					'name'          => 'options',
					'type'          => 'repeatable-fields',
					'class'         => 'manage',
					'id'            => 'manage',
					'fields'        => array($option_name, $option_value,$option_default, $option_price),
					'desc'          => __('Field options', 'ofb'),
					'row_class'     => 'ofb-option-row',
					'popup'         => true,
					'popup_button'  => __('Manage options', 'ofb'),
					'popup_title'   => __('Options', 'ofb'),
					'add_btn_label' => __('Add option', 'ofb'),
				)
			);

			$components = apply_filters(
				'vpc_form_components_fields',
				array(
					'title'           => __('Components', 'ofb'),
					'name'            => 'ofb[components]',
					'type'            => 'repeatable-fields',
					'id'              => 'ofb-config-components-table',
					'fields'          => array($type, $label, $name, $required,$option_min, $option_max, $length, $price, $options),
					'ignore_desc_col' => true,
					'class'           => 'striped',
					'add_btn_label'   => __('Add field', 'ofb'),
				)
			);
			$end      = array('type' => 'sectionend');
			$settings = array(
				$begin,
				$components,
				$end,
			);
			echo wp_kses(o_admin_fields($settings), get_allowed_tags());
			global $o_row_templates;
			?>
		</div>
		<script>
			var o_rows_tpl = <?php echo wp_json_encode($o_row_templates); ?>;
		</script>

	<?php
	}

	/**
	 *  Save ofb form post type
	 *
	 * @param type $post_id The form post ID.
	 */
	public function save_post_callback($post_id)
	{
		$meta_key = 'ofb';
		if (isset($_POST[$meta_key])) { // phpcs:ignore
			$form_datas = $_POST[$meta_key]; // phpcs:ignore
			foreach ($form_datas['components'] as $key => $components) {
				if (isset($components['name']) && empty($components['name'])) {
					$label = $components['label'];
					if (empty($label)) {
						$label                                     = $components['type'];
						$form_datas['components'][$key]['label'] = $label;
					}
					$form_datas['components'][$key]['name'] = sanitize_title($label) . '_' . $key;
				}
				if ('checkbox' === $components['type'] || 'radio' === $components['type']) {
					foreach ($components['options'] as $opt_key => $options) {
						if ((isset($options['op_value']) && empty($options['op_value'])) && (isset($options['label']) && empty($options['label']))) {
							$form_datas['components'][$key]['options'][$opt_key]['label']    = $opt_key;
							$form_datas['components'][$key]['options'][$opt_key]['op_value'] = $opt_key;
						} elseif ((isset($options['op_value']) && empty($options['op_value'])) && (isset($options['label']) && !empty($options['label']))) {
							$form_datas['components'][$key]['options'][$opt_key]['op_value'] = $options['label'] . '_' . $opt_key;
						} elseif ((isset($options['op_value']) && !empty($options['op_value'])) && (isset($options['label']) && empty($options['label']))) {
							$form_datas['components'][$key]['options'][$opt_key]['label'] = $options['op_value'] . '_' . $opt_key;
						}
					}
				}
			}
			update_post_meta($post_id, $meta_key, $form_datas);
		}
	}

	/**
	 * Get max input vars
	 */
	public function get_max_input_vars_php_ini()
	{
		$total_max_normal = ini_get('max_input_vars');
		$msg              = __('Your max input var is', 'vpc-ofb') . '<strong>' . $total_max_normal . '</strong>' . __('but this page contains', 'vpc') . '<strong>{nb}</strong>' . __('fields. You may experience a lost of data after saving. In order to fix this issue, please increase', 'vpc') . '<strong>' . __('the max_input_vars', 'vpc') . '</strong>' . __('value in your php.ini file', 'vpc');
	?>

		<script type="text/javascript">
			var o_max_input_vars = <?php echo esc_html($total_max_normal); ?>;
			var o_max_input_msg = "<?php echo esc_html($msg); ?>";
		</script>
<?php
	}
}
